@@ -21,7 +21,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // Self
 #include "filtercontroller.h"
 
-
 // Qt
 #include <QAction>
 #include <QCompleter>
@@ -30,20 +29,20 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QPainterPath>
 #include <QTimer>
 #include <QToolButton>
-#include "gwenview_app_debug.h"
 #include <QIcon>
 
-// KDE
+// KF
 #include <KComboBox>
 #include <KIconLoader>
 #include <KLocalizedString>
 
 // Local
+#include "gwenview_app_debug.h"
 #include <lib/flowlayout.h>
 #include <lib/paintutils.h>
 
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
-// KDE
+// KF
 
 // Local
 #endif
@@ -287,7 +286,7 @@ FilterController::FilterController(QFrame* frame, SortedDirModel* dirModel)
 
     addAction(i18nc("@action:inmenu", "Filter by Name"),
               SLOT(addFilterByName()),
-              QKeySequence(Qt::CTRL + Qt::Key_I));
+              QKeySequence(Qt::CTRL | Qt::Key_I));
 
     addAction(i18nc("@action:inmenu", "Filter by Date"),
               SLOT(addFilterByDate()),
