@@ -25,10 +25,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QItemSelectionModel>
 #include <QShortcut>
 #include <QVBoxLayout>
-#include "gwenview_app_debug.h"
 #include <QMenu>
 
-// KDE
+// KF
 #include <KActionCollection>
 #include <KActionCategory>
 #include <KLocalizedString>
@@ -41,6 +40,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #endif
 
 // Local
+#include "gwenview_app_debug.h"
 #include "fileoperations.h"
 #include <gvcore.h>
 #include "splitter.h"
@@ -445,13 +445,13 @@ ViewMainPage::ViewMainPage(QWidget* parent, SlideShow* slideShow, KActionCollect
     d->mToggleThumbnailBarAction = view->add<KToggleAction>(QStringLiteral("toggle_thumbnailbar"));
     d->mToggleThumbnailBarAction->setText(i18n("Thumbnail Bar"));
     d->mToggleThumbnailBarAction->setIcon(QIcon::fromTheme(QStringLiteral("folder-image")));
-    actionCollection->setDefaultShortcut(d->mToggleThumbnailBarAction, Qt::CTRL + Qt::Key_B);
+    actionCollection->setDefaultShortcut(d->mToggleThumbnailBarAction, Qt::CTRL | Qt::Key_B);
     connect(d->mToggleThumbnailBarAction, &KToggleAction::triggered, this, &ViewMainPage::setThumbnailBarVisibility);
     d->mToggleThumbnailBarButton->setDefaultAction(d->mToggleThumbnailBarAction);
 
     d->mSynchronizeAction = view->add<KToggleAction>("synchronize_views");
     d->mSynchronizeAction->setText(i18n("Synchronize"));
-    actionCollection->setDefaultShortcut(d->mSynchronizeAction, Qt::CTRL + Qt::Key_Y);
+    actionCollection->setDefaultShortcut(d->mSynchronizeAction, Qt::CTRL | Qt::Key_Y);
     connect(d->mSynchronizeAction, &QAction::toggled,
             d->mSynchronizer, &DocumentViewSynchronizer::setActive);
     // Ensure mSynchronizeAction and mSynchronizeCheckBox are in sync
@@ -571,6 +571,7 @@ void ViewMainPage::showContextMenu()
         addActionToMenu(&menu, d->mActionCollection, "view_zoom_to_fit");
         addActionToMenu(&menu, d->mActionCollection, "view_zoom_in");
         addActionToMenu(&menu, d->mActionCollection, "view_zoom_out");
+        addActionToMenu(&menu, d->mActionCollection, "view_toggle_birdeyeview");
     }
     if (d->mCompareMode) {
         menu.addSeparator();
@@ -656,7 +657,11 @@ void ViewMainPage::openUrls(const QList<QUrl>& allUrls, const QUrl &currentUrl)
 {
     DocumentView::Setup setup;
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    QSet<QUrl> urls(allUrls.begin(), allUrls.end());
+#else
     QSet<QUrl> urls = allUrls.toSet();
+#endif
     d->mCompareMode = urls.count() > 1;
 
     typedef QMap<QUrl, DocumentView*> ViewForUrlMap;
