@@ -26,7 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // Qt
 #include <QGraphicsWidget>
 
-// KDE
+// KF
 
 // Local
 #include <lib/document/document.h>
@@ -127,7 +127,6 @@ public:
     void moveToAnimated(const QRect&);
     QPropertyAnimation* fadeIn();
     void fadeOut();
-    void fakeFadeOut();
 
     void setGeometry(const QRectF& rect) override;
 
@@ -150,6 +149,7 @@ public Q_SLOTS:
 
     void setZoomToFill(bool);
     void toggleZoomToFill();
+    void toggleBirdEyeView();
 
     void setPosition(const QPoint&);
 
