@@ -22,13 +22,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 // Qt
 #include <QSignalSpy>
-
-// KDE
 #include <QDebug>
-#include <KRandom>
 #include <QTemporaryFile>
 #include <QTest>
 
+// KF
+#include <KRandom>
+
 // Local
 #include "testutils.h"
 #include <config-gwenview.h>
@@ -71,9 +71,9 @@ void SemanticInfoBackEndTest::initTestCase()
 void SemanticInfoBackEndTest::init()
 {
 #ifdef GWENVIEW_SEMANTICINFO_BACKEND_FAKE
-    mBackEnd = new FakeSemanticInfoBackEnd(0, FakeSemanticInfoBackEnd::InitializeEmpty);
+    mBackEnd = new FakeSemanticInfoBackEnd(nullptr, FakeSemanticInfoBackEnd::InitializeEmpty);
 #elif defined(GWENVIEW_SEMANTICINFO_BACKEND_BALOO)
-    mBackEnd = new BalooSemanticInfoBackend(0);
+    mBackEnd = new BalooSemanticInfoBackend(nullptr);
 #endif
 }
 
